@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# __coconut_hash__ = 0x7340207
+# __coconut_hash__ = 0x2b6a950a
 
 # Compiled with Coconut version 1.5.0-post_dev58 [Fish License]
 
@@ -160,6 +160,10 @@ _coconut_call_set_names(Expr)
 class Top(Expr):
     """True"""
     __slots__ = ()
+    def __init__(self, *args, **kwargs):
+# type: (...) -> None
+        super(Top, self).__init__(*args, **kwargs)
+        self.elems = None
     @_coconut_tco
     def __eq__(self, other):
         return _coconut_tail_call(isinstance, other, Top)
